Documentation
¶
Overview ¶
Package vtworkerservice is a generated protocol buffer package.
It is generated from these files:
vtworkerservice.proto
It has these top-level messages:
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterVtworkerServer ¶
func RegisterVtworkerServer(s *grpc.Server, srv VtworkerServer)
Types ¶
type VtworkerClient ¶
type VtworkerClient interface {
// ExecuteVtworkerCommand allows to run a vtworker command by specifying the
// same arguments as on the command line.
ExecuteVtworkerCommand(ctx context.Context, in *vtworkerdata.ExecuteVtworkerCommandRequest, opts ...grpc.CallOption) (Vtworker_ExecuteVtworkerCommandClient, error)
}
func NewVtworkerClient ¶
func NewVtworkerClient(cc *grpc.ClientConn) VtworkerClient
type VtworkerServer ¶
type VtworkerServer interface {
// ExecuteVtworkerCommand allows to run a vtworker command by specifying the
// same arguments as on the command line.
ExecuteVtworkerCommand(*vtworkerdata.ExecuteVtworkerCommandRequest, Vtworker_ExecuteVtworkerCommandServer) error
}
type Vtworker_ExecuteVtworkerCommandClient ¶
type Vtworker_ExecuteVtworkerCommandClient interface {
Recv() (*vtworkerdata.ExecuteVtworkerCommandResponse, error)
grpc.ClientStream
}
type Vtworker_ExecuteVtworkerCommandServer ¶
type Vtworker_ExecuteVtworkerCommandServer interface {
Send(*vtworkerdata.ExecuteVtworkerCommandResponse) error
grpc.ServerStream
}
Click to show internal directories.
Click to hide internal directories.